<?php

// Get theme options
$purplepastels_theme_options = get_option('purplepastels_theme_options');

// Load custom theme options
require_once get_template_directory() . '/library/theme-options.php';

// Theme setup
if( ! function_exists( 'purplepastels_theme_setup' ) ):
function purplepastels_theme_setup() {
	global $purplepastels_theme_options;

	// Load language files
	load_theme_textdomain( 'purplepastels', TEMPLATEPATH . '/langs' );
	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/langs/$locale.php";
	if( is_readable( $locale_file ) ) require_once( $locale_file );

	// add theme support
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );

	// Add editor style
	add_editor_style();

	// Set content width
	if( ! isset( $content_width ) ) $content_width = 955;

	// Add thickbox
	if(!isset($purplepastels_theme_options['thickbox']) || $purplepastels_theme_options['thickbox'] == 'yes') {
		add_action('template_redirect', 'purplepastels_thickbox_init');
		add_action('wp_footer', 'purplepastels_load_tb_fix');
		add_action('wp_print_styles', 'purplepastels_add_custom_thickbox_style');
	}

	set_post_thumbnail_size( get_option('thumbnail_size_w'), get_option('thumbnail_size_h') );

	// Set up custom post-thumbnail sizes
	if( isset($purplepastels_theme_options['pt_width']) && $purplepastels_theme_options['pt_width'] > 0 ) $pt_width = $purplepastels_theme_options['pt_width'];
	else $pt_width = 150;
	if( isset($purplepastels_theme_options['pt_height']) && $purplepastels_theme_options['pt_height'] > 0 ) $pt_height = $purplepastels_theme_options['pt_height'];
	else $pt_height = 150;
	if( isset($purplepastels_theme_options['pt_crop']) && $purplepastels_theme_options['pt_crop'] == 'hard' ) add_image_size( 'custom', $pt_width, $pt_height, true );
	else add_image_size( 'custom', $pt_width, $pt_height );

	// Set up custom post excerpt
	function purplepastels_excerpt_length() {
		global $purplepastels_theme_options;
		if( isset($purplepastels_theme_options['custom_excerpt']) && $purplepastels_theme_options['custom_excerpt'] > 0 ) return $purplepastels_theme_options['custom_excerpt'];
		else return 100;
	}
	add_filter('excerpt_length', 'purplepastels_excerpt_length');

}
endif;
add_action( 'after_setup_theme', 'purplepastels_theme_setup' );

// add custom menu support
if( function_exists( 'register_nav_menu' ) && !function_exists( 'purplepastels_register_menus' )) :
function purplepastels_register_menus() {
	register_nav_menu( 'toptabs', __( 'Top Tabs', 'purplepastels' ) );
}
add_action( 'init', 'purplepastels_register_menus' );
endif;

// Add accordion menu
if( !isset($purplepastels_theme_options['accordian']) || $purplepastels_theme_options['accordian'] == 'yes' &&  !is_admin() ) add_action('init', 'purplepastels_init_accordian');

// Output stylesheet links
if( !function_exists( 'purplepastels_stylesheets') ) :
function purplepastels_stylesheets() {
echo '<link rel="stylesheet" type="text/css" href="' . get_stylesheet_uri() . '" media="screen,print" />' ."\n";
echo '<link rel="stylesheet" type="text/css" href="' . get_stylesheet_directory_uri() . '/color.css" media="screen" />' ."\n";
echo '<link rel="stylesheet" type="text/css" href="' . get_stylesheet_directory_uri() . '/print.css" media="print" />' ."\n";
echo '<!--[if IE]><link rel="stylesheet" href="' . get_stylesheet_directory_uri() . '/ie.css" media="screen" type="text/css" /><![endif]-->' . "\n";
echo "<!--[if lte IE 7]>\n";
echo '<link rel="stylesheet" href="' . get_stylesheet_directory_uri() . '/ie7.css" media="screen" type="text/css" />' . "\n";
echo '<script src="' . get_template_directory_uri() . '/library/focus.js" type="text/javascript"></script>' . "\n";
echo "<![endif]-->\n";
}
endif;
add_action( 'wp_head', 'purplepastels_stylesheets' );

// Output designer meta tags
if( !function_exists( 'purplepastels_designer') ) :
function purplepastels_designer() {
?>
<meta name="designer" content="Mel P." />
<?php
}
endif;
add_action( 'wp_head', 'purplepastels_designer' );

// Register widgets
if(!function_exists('purplepastels_widgets_init')) :
function purplepastels_widgets_init() {
	register_sidebar(array(
		'name'=> 'Default Sidebar Upper',
		'id' => 'default-upper',
		'description' => __('Upper vertical sidebar','purplepastels'),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name'=> 'Default Sidebar Lower',
		'id' => 'default-lower',
		'description' => __('Lower vertical sidebar','purplepastels'),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name'=> 'Archives Sidebar Upper',
		'id' => 'archive-upper',
		'description' => __('Upper vertical sidebar for archive pages only','purplepastels'),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name'=> 'Archives Sidebar Lower',
		'id' => 'archive-lower',
		'description' => __('Lower vertical sidebar for archive pages only','purplepastels'),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name'=> 'Alt Page Sidebar Upper',
		'id' => 'alt-page-upper',
		'description' => __('Upper vertical sidebar for the Alternative Page template','purplepastels'),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name'=> 'Alt Page Sidebar Lower',
		'id' => 'alt-page-lower',
		'description' => __('Lower vertical sidebar for the Alternative Page template','purplepastels'),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name'=> 'Widget Page Upper',
		'id' => 'widget-page-upper',
		'description' => __('Before page content','purplepastels'),
		'before_widget' => '<div id="%1$s" class="widgetbox %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name'=> 'Widget Page Lower',
		'id' => 'widget-page-lower',
		'description' => __('After page content','purplepastels'),
		'before_widget' => '<div id="%1$s" class="widgetbox %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
}
endif;
add_action( 'widgets_init', 'purplepastels_widgets_init' );

// Hide widget titles
if( !function_exists( 'purplepastels_widgettitles' ) ) :
function purplepastels_widgettitles() {
?>
<style type = "text/css">.widgettitle {position:absolute;top:-9000px;left:-9000px;}</style><?php
}
endif;
if(isset($purplepastels_theme_options['display_widget_titles']) && $purplepastels_theme_options['display_widget_titles'] == 'no' ) add_action( 'wp_head', 'purplepastels_widgettitles' );

// Disable home link in wp_page_menu
if( !function_exists( 'purplepastels_show_home' ) ) :
function purplepastels_show_home( $args ) {
	$args['show_home'] = true;
	return $args;
}
endif;
add_filter( 'wp_page_menu_args', 'purplepastels_show_home' );

// Custom comment form fields
if( !function_exists( 'purplepastels_theme_comment_fields' ) ) :
	function purplepastels_theme_comment_fields($fields) {
		$commenter = wp_get_current_commenter();
		$req = get_option('require_name_email');
		if( $req ) $reqd = '<span class="required">' . __('*', 'purplepastels') . '</span>';

		$fields['author'] = '<p class="comment-form-author"><label class="text" for="author">' . __( 'Name', 'purplepastels' ) . $reqd . '</label><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" /></p>';

		$fields['email'] = '<p class="comment-form-email"><label class="text" for="email">' . __( 'Email', 'purplepastels' ) . $reqd . '</label><input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" />' . '</p>';

		$fields['url']   = '<p class="comment-form-url"><label class="text" for="url">' . __( 'Website', 'purplepastels') . '</label>' . '<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';

		return $fields;
	}
endif;
add_filter('comment_form_default_fields','purplepastels_theme_comment_fields');

// Custom comment form arguments
if( ! function_exists( 'purplepastels_theme_comment_form_args' ) ) :
	function purplepastels_theme_comment_form_args($user_identity, $post_id, $req) {
		global $purplepastels_theme_options;
		$args = array(
			'comment_notes_before' => '<p class="comment-notes"><label for="author">' . ( $req ? __( ' Required fields are marked ', 'purplepastels') . '<span class="required">' . __('*', 'purplepastels') . '</span><br />' : '' ) . __( 'Your details will be stored in a non-tracking cookie but your email address will <em>never</em> be published or shared.', 'purplepastels' ) . '</label></p>',

			'must_log_in' => '<p class="must-log-in">' .  sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment. If you choose to login - or register - on this site, a non-tracking cookie will be stored on your computer but your email address will <em>never</em> be published or shared.' ), wp_login_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',

			'logged_in_as' => '<p class="logged-in-as"><label for="comment">' . sprintf( __( 'Logged in as <a href="%s">%s</a>. <a href="%s" title="Log out of this account">Log out?</a></label></p>', 'purplepastels' ), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ),

			'comment_field' => '<p class="comment-form-comment"><label for="comment">' . _x( 'Comment', 'noun', 'purplepastels' ) . '</label><textarea id="comment" name="comment" cols="45" rows="8"></textarea></p>',
			'label_submit'=>'Submit Reply', 'purplepastels'
		);

		if(!isset($purplepastels_theme_options['display_kses']) || $purplepastels_theme_options['display_kses'] == 'yes') $args['comment_notes_after']  = '<p class="form-allowed-tags"><label for="comment">' . sprintf( __( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes: %s', 'purplepastels' ), ' <code>' . allowed_tags() . '</code>' ) . '</label></p>';
		else $args['comment_notes_after'] = '';

		return $args;
	}
endif;

// Make sure we always have a post/page title
if( !function_exists( 'purplepastels_correct_missing_title' ) ) :
function purplepastels_correct_missing_title( $title ) {
	if( $title == '' ) $title = __('No Title', 'purplepastels');
	return $title;
}
endif;
add_filter( 'the_title', 'purplepastels_correct_missing_title' );

// Amend post password form
if( !function_exists ('purplepastels_password_form') ) :
function purplepastels_password_form() {
	global $post;
	$label = 'pwbox-'.(empty($post->ID) ? rand() : $post->ID);
	$output = '<div class="password-form">
	<p class="protected-text">' . __('This post is password protected. To view it, please enter your password below:', 'purplepastels') . '</p>
	<form action="' . get_option('siteurl') . '/wp-pass.php" method="post">
	<p><label for="' . $label . '">' . __('Password:', 'purplepastels') . ' </label> <input name="post_password" id="' . $label . '" type="password" size="20" /> <input type="submit" name="Submit" value="' . esc_attr__('Submit', 'purplepastels') . '" /></p></form></div>';
	return $output;
}
endif;
add_filter('the_password_form','purplepastels_password_form');

// Amend password protected standard excerpt
if( !function_exists ('purplepastels_password_excerpt') ) :
function purplepastels_password_excerpt($output) {
	global $post;
	if( post_password_required($post) ) $output = '<p class="pwd-protected">' . __('This is a password protected post.', 'purplepastels') . '</p>';
	return $output;
}
endif;
add_filter('the_excerpt','purplepastels_password_excerpt');

// Display a - b of x posts
if( !function_exists( 'purplepastels_theme_postlist_info' ) ) :
function purplepastels_theme_postlist_info($my_tot_pages, $paged, $found_posts) {
	if( $paged == '') $my_curr_page = 1;
	else 	$my_curr_page = $paged;
	$my_finish =  $my_curr_page * get_option('posts_per_page');
	if( $found_posts < $my_finish ) $my_finish = $found_posts;
	if( $paged == '') $my_start = 1; // first page
	elseif( $paged == $my_tot_pages ) $my_start = ($my_tot_pages-1) * get_option('posts_per_page') +1; // last page
	else $my_start = 1 + $my_finish - get_option('posts_per_page');
	if( $my_finish > 1 ) {
		$format = __('Displaying %1$s - %2$s of %3$s entries.','purplepastels') ;
		printf( $format, $my_start, $my_finish, $found_posts);
	}
	else _e('Displaying 1 entry.','purplepastels');
}
endif;

// Ouput attachment image size
if( !function_exists( 'purplepastels_attachment_image_size' ) ) :
function purplepastels_attachment_image_size($excerpt) {
	global $post;
	if( wp_attachment_is_image() ) {
		$metadata = wp_get_attachment_metadata();
		$excerpt .= '<br />' . sprintf( __('Full size image: %1$s x %2$s', 'purplepastels'), $metadata['width'], $metadata['height'] );
	}
	return $excerpt;
}
endif;
add_filter('get_the_excerpt',  'purplepastels_attachment_image_size');

// WIDGETS
/* Register widgets */
function purplepastels_load_widgets() {
	if( function_exists ( 'wp_login_form' ) ) register_widget( 'Login_Form_Widget' );
}
add_action( 'widgets_init', 'purplepastels_load_widgets' );

class Login_Form_Widget extends WP_Widget {
	function Login_Form_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'login-form-widget', 'description' => __('Display a form to login or register on your blog', 'purplepastels') );

		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'login-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'login-widget', __('Login Form', 'purplepastels'), $widget_ops, $control_ops );
	}
	// Widget pre-display
	function widget( $args, $instance ) {
			extract( $args );

			/* User-selected settings. */
			$title = apply_filters('widget_title', $instance['title'] );

			echo $before_widget;
			if ( $title ) echo $before_title . $title . $after_title;
			$form = wp_login_form(array('echo' => false));
			echo $this->widget_strip_unwanted($form);
			echo $after_widget;
	}
	// Widget strip tabindexing
	function widget_strip_unwanted($form) {
		$form = str_replace(' name="loginform"', '' , $form);
		$form = str_replace(' tabindex="10"', '' , $form);
		$form = str_replace(' tabindex="20"', '' , $form);
		$form = str_replace(' tabindex="100"', '' , $form);
		return $form;
	}
	// Widget save/update
	function update( $new_instance, $old_instance ) {
			$instance = $old_instance;
			/* Strip tags (if needed) and update the widget settings. */
			$instance['title'] = strip_tags( $new_instance['title'] );
			return $instance;
	}
	// Widget Admin form
	function form( $instance ) {
			/* Set up some default widget settings. */
			$defaults = array( 'title' => __('Login', 'purplepastels') );
			$instance = wp_parse_args( (array) $instance, $defaults ); ?>

			<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'purplepastels');?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" /></p>

			<?php
	}
}

// Set up a proper &hellip;for post extracts
function purplepastels_proper_hellip($more) {
	return '&hellip;';
}
add_filter('excerpt_more', 'purplepastels_proper_hellip');

// remove gallery css
function purplepastels_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
add_filter( 'gallery_style', 'purplepastels_remove_gallery_css' );

// Create decent attachment links
function purplepastels_attachment_link($id) {
	// grab file extension
	$bits = explode('.',get_attached_file($id));
	$ext = '.'.$bits[count($bits)-1].' format';
	// get the icon link
	$icon_link = wp_get_attachment_link($id,'thumbnail',false,true);
	// get the text link
	$text_link = wp_get_attachment_link($id,'',false,false);
	// get the filesize in kilobytes
	if(@filesize(get_attached_file($id))) {
		 $filesize = ceil(filesize(get_attached_file($id))/1024).'K';
		 return $icon_link. ' '.$text_link .' <small>(' .$ext .' ' . $filesize .')</small>';
	}
	else return $icon_link . ' ' . $text_link .' <small>(' . $ext . ')</small>';
}

// Accordion menu setup
function purplepastels_init_accordian() {
	wp_enqueue_script('accordian',
    get_template_directory_uri() . '/library/accordian-menu.js',
	 array('jquery'),
	'3.0.2'
	);
}

// Thickbox setup
function purplepastels_thickbox_init() {
	if (wp_attachment_is_image() ) add_thickbox();
}
function purplepastels_load_tb_fix() {
	if( is_attachment() ) :?>
<script type="text/javascript">tb_pathToImage = "'<?php echo home_url('/');?>/wp-includes/js/thickbox/loadingAnimation.gif";tb_closeImage = "<?php echo home_url('/');?>/wp-includes/js/thickbox/tb-close.png";</script>
	<?php endif;
}
function purplepastels_add_custom_thickbox_style() {
	if ( is_attachment() ) {
		wp_register_style('custom-thickbox', get_stylesheet_directory_uri() . '/library/custom-thickbox.css', '', '', 'screen');
		wp_enqueue_style('custom-thickbox');
	}
}

// Generate page tree
function purplepastels_page_tree($this_page) {
	$pagelist = '';
	if( !$this_page->post_parent ) {
		$children = wp_list_pages('title_li=&child_of='.$this_page->ID.'&echo=0');
		if( $children ) {
			$pagelist .= '<li class="current_page_item"><a href="'.  get_page_link($this_page->ID) .'">' . $this_page->post_title . '</a>';
			$pagelist .= '<ul>' . $children . '</ul>';
			$pagelist .= '</li>';
		}
	}
	elseif( $this_page->ancestors ) {
		// get the top ID of this page. Page ids DESC so top level ID is the last one
		$ancestor = end($this_page->ancestors);
		$pagelist .= wp_list_pages('title_li=&include='.$ancestor.'&echo=0');
		$pagelist = str_replace('</li>', '', $pagelist);
		$pagelist .= '<ul>' . wp_list_pages('title_li=&child_of='.$ancestor.'&echo=0') .'</ul></li>';
	}
	return $pagelist;
}

// Get archive date
function purplepastels_get_archive_date() {
	if (is_day()) $this_archive = get_the_time('j F Y');
	elseif (is_month()) $this_archive = get_the_time('F Y');
	else $this_archive = get_the_time('Y');
	return $this_archive;
}

// get category & it's children as an array of ids
function purplepastels_get_cat_tree($parent) {
	$term_objs = get_term_children( $parent, 'category' );
	$term_objs[] =$parent;
	return $term_objs;
}

/* purplepastels_enhanced_cat_list
*  Echoes the wp_list_categories output with extra class applied to the topmost parent category.
*  Relies on purplepastels_top_cats()
* @param string $curr_cat: Current Category ID
* @param string $catlist: Ouput from wp_list_categories
* @param string Optional $extra_class: Additonal class to be added to the li element. Defaults to 'current-cat-ancestor'.
*
**/
function purplepastels_enhanced_cat_list($curr_cat_id,$catlist, $extra_class='current-cat-ancestor') {
	$top_cats = purplepastels_top_cats();
	foreach( $top_cats as $top_cat) {
		if( cat_is_ancestor_of($top_cat, $curr_cat_id) ) {
			$cat_ancestor_class = 'cat-item-'. $top_cat;
			$amended_class = $cat_ancestor_class . ' ' . $extra_class;
			break;
		}
		else $cat_ancestor_class = '';
	}
	if( $cat_ancestor_class != '' && stristr( $catlist, $cat_ancestor_class) ) $new_catlist = str_replace($cat_ancestor_class, $amended_class, $catlist );
	else $new_catlist = $catlist;
	echo $new_catlist;
}

// Get ids for all top level (parent) categories
// Used by purplepastels_enhanced_cat_list
function purplepastels_top_cats() {
	$toplevel = array();
	$allcats = get_terms('category', 'orderby=name&hide_empty=0');
	foreach( $allcats as $cat ) {
		if( $cat->parent == 0) $toplevel[] = $cat->term_id;
	}
	return $toplevel;
}

// HEADER & BACKGROUND CUSTOMISATION

define('HEADER_IMAGE_WIDTH', apply_filters( 'purplepastels_header_image_width',960 ) );
define('HEADER_IMAGE_HEIGHT', apply_filters( 'purplepastels_header_image_height', 139 ) );
define('HEADER_IMAGE', apply_filters( 'purplepastels_header_image', get_stylesheet_directory_uri() . '/images/header.jpg') );
define('HEADER_TEXTCOLOR', apply_filters( 'purplepastels_header_textcolor','64468B') );

// Background customisation
// Add support for custom background
if( function_exists ('add_custom_background') ) add_custom_background($header_callback = 'purplepastels_custom_background_cb', $admin_header_callback = '', $admin_image_div_callback = 'purplepastels_admin_image_div_callback');

define ('BACKGROUND_COLOR', apply_filters( 'purplepastels_background_color','f4f1f5') );
define ('BACKGROUND_IMAGE',  apply_filters( 'purplepastels_background_image', get_stylesheet_directory_uri()  . '/images/left.jpg') );
define ('BACKGROUND_IMAGE_RIGHT',  apply_filters( 'purplepastels_header_image_right', get_stylesheet_directory_uri() . '/images/right.jpg') );

/* Custom background callback for site display */
if( ! function_exists( 'purplepastels_custom_background_cb' ) ) :
function purplepastels_custom_background_cb() {
	$background = get_background_image();
	$color = get_background_color();
	if( ! $background && ! $color )
		return;

	$style = $color ? "background-color: #$color;" : '';

	if( $background ) {
		$image = " background-image: url('$background');";

		$repeat = get_theme_mod( 'background_repeat', 'no-repeat' );
		if( ! in_array( $repeat, array( 'no-repeat', 'repeat-x', 'repeat-y', 'repeat' ) ) ) $repeat = 'repeat';
		$repeat = " background-repeat: $repeat;";

		$position = get_theme_mod( 'background_position_x', 'left' );
		if( ! in_array( $position, array( 'center', 'right', 'left' ) ) ) $position = 'left';
		$position = " background-position: top $position;";

		$attachment = get_theme_mod( 'background_attachment', 'fixed' );
		if( ! in_array( $attachment, array( 'fixed', 'scroll' ) ) ) $attachment = 'scroll';
		$attachment = " background-attachment: $attachment;";

		$style .= $image . $repeat . $position . $attachment;

		if( $background != BACKGROUND_IMAGE ) $outer_style = 'background:transparent;';
		else $outer_style = '';
	}
	else {
		$style .= 'background-image:none;';
		$outer_style = 'background-image:none;';
	}
?>
<style type="text/css">
html { <?php echo trim( $style ); ?> }
<?php if( $outer_style != '') :?> #outer {<?php echo $outer_style;?>}<?php endif;?>
</style>
<?php
}
endif;

/* Custom background callback for admin display */
if( ! function_exists( 'purplepastels_admin_image_div_callback' ) ) :
function purplepastels_admin_image_div_callback() {
	?>
	<h3><?php _e('Background Image', 'purplepastels'); ?></h3>
	<table class="form-table">
	<tbody>
	<tr valign="top">
	<th scope="row"><?php _e('Preview', 'purplepastels'); ?></th>
	<td>
	<?php
	$background_styles = '';
	if( $bgcolor = get_background_color() ) $background_styles .= 'background-color: #' . $bgcolor . ';';

	if( get_background_image() ) {
		if( get_background_image() != BACKGROUND_IMAGE ) {
			$background_styles .= ' background-image: url(\'' . get_theme_mod('background_image_thumb', '') . '\');'
				. ' background-repeat: ' . get_theme_mod('background_repeat', 'repeat') . ';'
				. ' background-position: top ' . get_theme_mod('background_position_x', 'left');
		}
		else {
			$background_styles .= ' background-image: url(' . BACKGROUND_IMAGE . ');'
				. ' background-repeat:no-repeat;'
				. ' background-position: left top;'
				. ' height:300px;';
				set_theme_mod('background_color', BACKGROUND_COLOR);
				set_theme_mod('background_repeat', 'no-repeat');
				set_theme_mod('background_position_x', 'left');
				set_theme_mod( 'background_attachment', 'fixed' );
		}
	}
	?>
	<div id="custom-background-image" style="<?php echo $background_styles; ?>">
	<?php if( get_background_image() == BACKGROUND_IMAGE ) { ?>
		<div style="background:url(<?php echo BACKGROUND_IMAGE_RIGHT;?>);background-repeat:no-repeat; background-position:right top;height:300px;">
		<?php
	}

	if( get_background_image() ) :
	if( get_background_image() != BACKGROUND_IMAGE ) : ?>
	<img class="custom-background-image" src="<?php echo get_theme_mod('background_image_thumb', ''); ?>" style="visibility:hidden;" alt="" /><br />
	<img class="custom-background-image" src="<?php echo get_theme_mod('background_image_thumb', ''); ?>" style="visibility:hidden;" alt="" />
	<?php endif; endif; ?>
	</div>
	<?php
}
endif;

// output header image & text CSS
if( !function_exists( 'purplepastels_theme_custom_header_style' ) ) :
function purplepastels_theme_custom_header_style() {
	echo '<style type="text/css" media="screen">'."\n";
	if( get_header_image() != '' ) echo '#headimg {background-image:url(' . get_header_image() . ');}';
	else echo '#headimg {background-image:none;}';
	if( get_header_textcolor() == 'blank' ) echo '#blogtitle h1 {position:absolute;top:-5000px;left:-5000px;}';
	else echo '#blogtitle,#blogtitle h1 a,#blogtitle h1 span {color:#' . get_header_textcolor() . ';}';
	echo "\n</style>\n\n";
}
endif;

// Style header customisation in the Admin area
if( !function_exists( 'purplepastels_theme_admin_header_style' ) ) :
function purplepastels_theme_admin_header_style() {
?>
<style type="text/css">
#headimg {
	height:139px;
	padding:0;
	margin:0;
	color:#64468B;
	background-color:#CFCEF8;
	background-repeat:no-repeat;
	background-position: right top;
}
#headimg h1,#headimg #desc {
	font-family:georgia,times,'times new roman',serif;
	letter-spacing:.02em;
}
#headimg h1 {
	margin:0;
	padding:5px 0 0 15px;
	font-size:2.8em;
	font-weight:normal;
	line-height:1.2em;
	font-style:italic;
}
#headimg a {
	text-decoration:none;
}
#headimg a:hover,#headimg a:active,#headimg a:focus {
	text-decoration:underline;
}
#headimg #desc {
	margin:0 0 20px;
	padding:8px;
	font-size:1.6em;
	text-indent:1.2em;
}
</style>
<?php
}
endif;
add_custom_image_header('', 'purplepastels_theme_admin_header_style');
