<?php

// Load theme options
require_once get_template_directory() . '/library/pp-theme-options-array.php';

// White list theme options
function theme_options_init() {
	register_setting( 'theme_options', 'purplepastels_theme_options', 'theme_options_validate' );
}
add_action( 'admin_init', 'theme_options_init' );

// Add theme options page
function theme_options_add_page() {
	add_theme_page( __( 'Theme Options', 'purplepastels' ), __( 'Theme Options', 'purplepastels' ), 'edit_theme_options', 'pp_theme_options', 'pp_theme_options_do_page' );
}
add_action('admin_menu', 'theme_options_add_page');

// Load theme options stylesheet
function pp_theme_options_add_style() {
	wp_register_style('purple_pastels_options_style', get_template_directory_uri() . '/library/theme-options.css', '', '', 'screen');
	if ( file_exists( get_template_directory() . '/theme-options-custom.css' ) ) {
		wp_register_style('purple_pastels_options_custom_style',get_template_directory_uri() . '/theme-options-custom.css', '', '', 'screen');
	}
}
function pp_theme_options_enqueue_style() {
	wp_enqueue_style('purple_pastels_options_style');
	wp_enqueue_style('purple_pastels_options_custom_style');
}
add_action('admin_init', 'pp_theme_options_add_style');
add_action('admin_print_styles', 'pp_theme_options_enqueue_style');


// Add basic contextual help links
function add_pp_contextual_help() {
	$help = '<ul class="contextual-links">';
	$help .= '<li><a href="http://quirm.net/forum/forum.php?id=15">' .__( 'Purple Pastels support on Quirm.net', 'purplepastels') . '</a></li>';
	$help .= '<li><a href="http://wordpress.org/tags/purple-pastels">' .__( 'Purple Pastels support on wordress.org', 'purplepastels') . '</a></li>';
	$help .= '</ul>';
   add_contextual_help( 'appearance_page_pp_theme_options', $help );
}
add_action('admin_init','add_pp_contextual_help');


// Theme options form
function pp_theme_options_do_page() {
	global  $all_theme_options;
	if ( ! isset( $_REQUEST['updated'] ) ) $_REQUEST['updated'] = false;
	?>

	<div class="wrap">
	<?php screen_icon(); echo "<h2>" . get_current_theme() . __( ' Theme Options', 'purplepastels') . "</h2>"; ?>

	<?php if ( false !== $_REQUEST['updated'] ) : ?>
	<div class="updated fade"><p><strong><?php _e( 'Your theme options have been saved', 'purplepastels'); ?></strong></p></div>
	<?php endif;?>

	<?php include_once 'donate.php';?>

	<form method="post" action="options.php" id="purplepastels_theme_options"><div>
	<?php settings_fields( 'theme_options' ); ?>
	<?php $stored_options = get_option('purplepastels_theme_options');
	?>

	<fieldset>
	<legend><?php _e('Collapsing sub-menus (vertical sidebar)', 'purplepastels'); ?></legend>
	<?php $option_name = 'accordian';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset class="pt-size">
	<legend><?php _e('Featured Post Image Size', 'purplepastels'); ?></legend>
	<?php $option_name = 'pt_width';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?><br />
	<?php $option_name = 'pt_height';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Featured Post Image Cropping', 'purplepastels'); ?></legend>
	<?php $option_name = 'pt_crop';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Post Excerpt Length', 'purplepastels'); ?></legend>
	<?php $option_name = 'custom_excerpt';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Pages in this section list', 'purplepastels'); ?></legend>
	<?php $option_name = 'display_subpages';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Allowed Tags (comment form)', 'purplepastels'); ?></legend>
	<?php $option_name = 'display_kses';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Post Numbers (a - b of x entries)', 'purplepastels'); ?></legend>
	<?php $option_name = 'display_postlist';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Widget Titles ', 'purplepastels'); ?></legend>
	<?php $option_name = 'display_widget_titles';
	pp_theme_options_sort( $all_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Update Theme', 'purplepastels') ?>" /></p>

	</div></form>
</div>
	<?php
}

// sort inputs for display
function pp_theme_options_sort($option_input, $stored_options, $name) {
	switch ($option_input['type']) {
		case 'radio':
		pp_theme_options_do_radio($option_input['options'], $stored_options, $name, $option_input['default']);
		break;

		case 'text':
		pp_theme_options_do_text($option_input, $stored_options, $name);
		break;

		default:
		break;
	}
}

// Radio button display
function pp_theme_options_do_radio($radio_options, $stored_options, $name, $default) {
	if ( ! isset( $checked ) ) $checked = '';
	foreach ( $radio_options as $option ) {
		if ( isset( $stored_options[$name] ) ) {
			if( $stored_options[$name] == $option['value'] ) $checked = 'checked="checked"';
			else $checked = '';
		}
		else{
			if ( $option['value']  ==  $default ) $checked = 'checked="checked"';
			else $checked = '';
		}?>
		<label class="description" for="<?php echo $name;?>_<?php esc_attr_e( $option['value'] ); ?>"><input type="radio" id="<?php echo $name;?>_<?php esc_attr_e( $option['value'] ); ?>" name="purplepastels_theme_options[<?php echo $name;?>]" value="<?php esc_attr_e( $option['value'] ); ?>" <?php echo $checked; ?> /> <?php echo $option['label']; ?></label>
		<?php
	}
}

// Text input display
function pp_theme_options_do_text($setting, $stored_options, $name) {
	if( isset( $stored_options[$name] ) ) {
		if( $setting['numeric'] == 1 ) {
			if( ctype_digit( $stored_options[$name] ) ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
		else {
			if( $stored_options[$name] != '' ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
	}
	else $current_value = $setting['default'];
	?>
	<label class="description text" for="<?php echo $name;?>"><?php echo $setting['label'];?></label> <input type="text" id="<?php echo $name;?>" name="purplepastels_theme_options[<?php echo $name;?>]" size="<?php echo $setting['size'];?>" maxlength="<?php echo $setting['maxlength'];?>" value="<?php echo $current_value;?>" />
	<?php
}

// Sanitize and validate inputs
function pp_theme_options_validate( $input ) {
	$new_input = array();
	global $all_theme_options;
	$theme_option_names = array_keys($all_theme_options);

	foreach($theme_option_names as $theme_option_name) {
		$option_type = $theme_option_name['type'];
		switch ($option_type) {
			case 'checkbox':
			$new_input[$theme_option_name] = ( $input[$theme_option_name] == 1 ? 1 : 0 );
			break;

			case 'text':
			$new_input[$theme_option_name] = wp_filter_nohtml_kses( $input[$theme_option_name] );
			break;

			case 'textarea':
			$new_input[$theme_option_name] = wp_filter_post_kses( $input[$theme_option_name] );
			break;

			default:
			$new_input[$theme_option_name] = $input[$theme_option_name];
		}
		if( !isset( $input[$theme_option_name] ) ) $new_input[$theme_option_name] = $theme_option_name['default'];
	}
	return $new_input;
}
